"use strict";var i=function(e,r){return function(){return r||e((r={exports:{}}).exports,r),r.exports}};var u=i(function(D,o){
var a=typeof Object.getOwnPropertyDescriptor!="undefined";o.exports=a
});var p=i(function(P,s){
var f=Object.getOwnPropertyDescriptor;function v(e,r){var t;return e==null?null:(t=f(e,r),t===void 0?null:t)}s.exports=v
});var l=i(function(q,c){
var b=require('@stdlib/assert-has-own-property/dist');function O(e,r){return b(e,r)?{configurable:!0,enumerable:!0,writable:!0,value:e[r]}:null}c.exports=O
});var w=u(),y=p(),d=l(),n;w?n=y:n=d;module.exports=n;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
